@@ -9,7 +9,6 @@
 #' @param state_second state of the second peptide
 #' @param chosen_time chosen time point
 #' @param in_time `in` time
-#' @param relative \code{logical}, determines if values are relative or absolute. 
 #' 
 #' @details The function calculates mean uncertainty of all peptides and its uncertainty (standard error) based on given `in_time` and `chosen_time` 
 #' as a function of `out_time`. Both theoretical and experimental results for each state and their difference are supplied for comparison but only 
@@ -30,8 +29,7 @@
 #'                            state_first = "CD160",
 #'                            state_second = "CD160_HVEM", 
 #'                            chosen_time = 1, 
-#'                            in_time = 0.001, 
-#'                            relative = TRUE))    
+#'                            in_time = 0.001))    
 #'                            
 #' # load extra libraries
 #' library(ggplot2)
@@ -39,7 +37,7 @@
 #' library(dplyr)
 #' 
 #' # example of data visualization 
-#' gather(result, 2:13, key = 'type', value = 'value') %>%
+#' gather(result, 2:7, key = 'type', value = 'value') %>%
 #' filter(startsWith(type, "avg")) %>%
 #'   ggplot(aes(x = factor(out_time), y = value, group = type)) +
 #'   geom_line(aes(color = type)) +
@@ -52,8 +50,7 @@ quality_control <- function(dat,
                             state_first,
                             state_second, 
                             chosen_time, 
-                            in_time,
-                            relative = TRUE){
+                            in_time){
   
   
   times <- unique(dat[["Exposure"]][dat["Exposure"] > chosen_time])
@@ -68,50 +65,21 @@ quality_control <- function(dat,
                            chosen_state_second = paste0(state_second, "_", chosen_time),
                            out_state_second = paste0(state_second, "_", t))
     
-    if (relative){
-      
-      data.frame(t,
-                 mean(tmp[["err_frac_exch_state_1"]], na.rm = TRUE),
-                 sd(tmp[["err_frac_exch_state_1"]], na.rm = TRUE),
-                 mean(tmp[["err_frac_exch_state_2"]], na.rm = TRUE),
-                 sd(tmp[["err_frac_exch_state_2"]], na.rm = TRUE),
-                 mean(tmp[["err_avg_theo_in_time_1"]], na.rm = TRUE),
-                 sd(tmp[["err_avg_theo_in_time_1"]], na.rm = TRUE),
-                 mean(tmp[["err_avg_theo_in_time_2"]], na.rm = TRUE),
-                 sd(tmp[["err_avg_theo_in_time_2"]], na.rm = TRUE),
-                 mean(tmp[["err_frac_exch"]], na.rm = TRUE),
-                 sd(tmp[["err_frac_exch"]], na.rm = TRUE),
-                 mean(tmp[["err_diff_theo_frac_exch"]], na.rm = TRUE),
-                 sd(tmp[["err_diff_theo_frac_exch"]], na.rm = TRUE))
-      
-    } else {
-      
-      data.frame(t,
-                 mean(tmp[["err_abs_frac_exch_state_1"]], na.rm = TRUE),
-                 sd(tmp[["err_abs_frac_exch_state_1"]], na.rm = TRUE),
-                 mean(tmp[["err_abs_frac_exch_state_2"]], na.rm = TRUE),
-                 sd(tmp[["err_abs_frac_exch_state_2"]], na.rm = TRUE),
-                 mean(tmp[["err_abs_avg_theo_in_time_1"]], na.rm = TRUE),
-                 sd(tmp[["err_abs_avg_theo_in_time_1"]], na.rm = TRUE),
-                 mean(tmp[["err_abs_avg_theo_in_time_2"]], na.rm = TRUE),
-                 sd(tmp[["err_abs_avg_theo_in_time_2"]], na.rm = TRUE),
-                 mean(tmp[["err_abs_diff_frac_exch"]], na.rm = TRUE),
-                 sd(tmp[["err_abs_diff_frac_exch"]], na.rm = TRUE),
-                 mean(tmp[["err_abs_diff_theo_frac_exch"]], na.rm = TRUE),
-                 sd(tmp[["err_abs_diff_theo_frac_exch"]], na.rm = TRUE))
-      
-    }
-    
+    data.frame(t,
+               mean(tmp[["err_frac_exch_state_1"]], na.rm = TRUE),
+               sd(tmp[["err_frac_exch_state_1"]], na.rm = TRUE),
+               mean(tmp[["err_frac_exch_state_2"]], na.rm = TRUE),
+               sd(tmp[["err_frac_exch_state_2"]], na.rm = TRUE),
+               mean(tmp[["err_frac_exch"]], na.rm = TRUE),
+               sd(tmp[["err_frac_exch"]], na.rm = TRUE))
     
   })
   
   result <- bind_rows(result)
   
   colnames(result) <- c("out_time", "avg_err_state_first", "sd_err_state_first", "avg_err_state_second", 
-                        "sd_err_state_second", "avg_err_theo_state_first", "sd_err_theo_state_first", 
-                        "avg_err_theo_state_second", "sd_err_theo_state_second", "avg_diff", 
-                        "sd_diff", "avg_theo_diff", "sd_theo_diff")
-
+                        "sd_err_state_second", "avg_diff", "sd_diff")
+  
   result
   
 }
