@@ -1,11 +1,7 @@
 source("data-work.R")
 
-#########################################
-
 options(spinner.color="#715D91")
 
-#########################################
-
 ui <- fluidPage(theme = "HaDeX_theme.css",
                 #titlePanel("HaDeX"), #: analysis of data from hydrogen deuterium exchange-mass spectrometry"),
                 title = "HaDeX",
@@ -24,8 +20,23 @@ ui <- fluidPage(theme = "HaDeX_theme.css",
                   ),
                   tabsetPanel(type = "pills",
                               tabPanel("Start",
-                                       h3("Welcome!"),
+                                       h3("Welcome to HaDeX!"),
+                                       h4("Thank you for using our tool."),
+                                       #h4("For any additional information, please see the documnetation available online.", a(href = "https://hadexversum.github.io/HaDeX/", "Check it out!")),
+                                       h4("Questions/feature requests/commercial applications: hadex@ibb.waw.pl"), 
+                                       includeMarkdown("readmes/about.md"),
+                                       img(class='funding-icons',
+                                           src='funding_icons.png'),
+                                       br()
+                                       
+                                       
+                              ),
+                              tabPanel("Input data",
+                                       br(),
                                        h4("Upload your file. Otherwise you will see example data."),
+                                       h4("Currently HaDeX is limited to `cluster` files from DynamX 3.0 and 2.0"),
+                                       h4("Accepted file extensions: .csv, .xsl, .xslx. "),
+                                       h4("Supplied file should containt at least two repetitions of the measurement fot the uncertainty to be calculated."),
                                        #
                                        fluidRow(
                                          column(3, 
@@ -44,8 +55,6 @@ ui <- fluidPage(theme = "HaDeX_theme.css",
                                        ),
                                        #
                                        h4("Please be aware that loading data (including example file) may take a while. Be patient."),
-                                       h4("Currently HaDeX supports files with only one protein."),
-                                       h4("Accepted file extensions: .csv, .xsl, .xslx. "),
                                        h4("In order for program to behave correctly, please make sure supplied file fulfills following requirements:"),
                                        tags$button("Show requirements", 
                                                    class = "collapse-button", 
@@ -57,9 +66,35 @@ ui <- fluidPage(theme = "HaDeX_theme.css",
                                          style = "width: min-content",
                                          class = "hideable",
                                          tableOutput("file_req")),
-                                       includeMarkdown("readmes/about.md"),
-                                       img(class='funding-icons',
-                                           src='funding_icons.png'),
+                                       h3("Settings"),
+                                       h4("Values chosen here are propagated into all of the tables for coherent results."),
+                                       fluidRow(
+                                         column(2, 
+                                                selectInput_h(inputId = "chosen_protein",
+                                                              label = "Choose protein: ",
+                                                              choices = c("db_CD160")),
+                                                selectInput_h(inputId = "chosen_control",
+                                                              label = "Choose maximal exchange control for chosen protein: ",
+                                                              choices = c("db_CD160 | CD160 | 1440")),
+                                                numericInput_h(inputId = "deut_concentration",
+                                                               label = "Choose D20 concentration [%]: ",
+                                                               value = 100,
+                                                               min = 0, max = 100, step = 1),
+                                                numericInput_h(inputId = "sequence_start_shift",
+                                                               label = "Move sequence start:",
+                                                               value = 1, 
+                                                               step = 1),
+                                                numericInput_h(inputId = "sequence_length",
+                                                               label = "Correct sequence length:",
+                                                               value = 300, 
+                                                               step = 1),
+                                                # h5("If C-terminal of is not covered by peptides, 
+                                                #         enter its correct position."),
+                                                textOutput("sequence_length_exp_info")
+                                         )
+                                       ),
+                                       br(),
+                                       br(),
                                        br()
                               ),
                               tabPanel("Woods plot",
@@ -67,40 +102,42 @@ ui <- fluidPage(theme = "HaDeX_theme.css",
                                        sidebarPanel(
                                          class = "scrollable",
                                          h3("Select parameters for the plot."),
-                                         checkboxInput(inputId = "theory",
-                                                       label = "Theoretical calculations",
-                                                       value = FALSE),
-                                         radioButtons(inputId = "calc_type",
-                                                      label = "Choose values type:",
-                                                      choices = c("relative", "absolute"),
-                                                      selected = "relative"),
+                                         fluidRow(checkboxInput_h(inputId = "theory",
+                                                                  label = "Theoretical calculations",
+                                                                  value = FALSE)),
+                                         radioButtons_h(inputId = "calc_type",
+                                                        label = "Choose values type:",
+                                                        choices = c("relative", "absolute"),
+                                                        selected = "relative"),
                                          h4("Comparison plot parameters:"),
                                          h5("Choose time parameters:"),
                                          splitLayout(
-                                           selectInput(inputId = "in_time",
-                                                       label = "IN",
-                                                       choices = c("0", "1", "5", "25", "1440")),
-                                           selectInput(inputId = "chosen_time",
-                                                       label = "CHOSEN",
-                                                       choices = c("0", "1", "5", "25", "1440")),
-                                           selectInput(inputId = "out_time",
-                                                       label = "OUT",
-                                                       choices = c("0", "1", "5", "25", "1440"))
+                                           selectInput_h(inputId = "in_time",
+                                                         label = "IN",
+                                                         choices = c("0", "1", "5", "25", "1440")),
+                                           selectInput_h(inputId = "chosen_time",
+                                                         label = "CHOSEN",
+                                                         choices = c("0", "1", "5", "25", "1440")),
+                                           selectInput_h(inputId = "out_time",
+                                                         label = "OUT",
+                                                         choices = c("0", "1", "5", "25", "1440"))
                                          ),
                                          ##
                                          fluidRow(
                                            column(6, 
                                                   h5("Choose states for comparison:"),
-                                                  checkboxGroupInput(inputId = "compare_states",
-                                                                     label = "",
-                                                                     choices = c("CD160", "CD160_HVEM"),
-                                                                     selected = c("CD160", "CD160_HVEM")),
+                                                  checkboxGroupInput_h(inputId = "compare_states",
+                                                                       label = "",
+                                                                       choices = c("CD160", "CD160VEM"),
+                                                                       selected = c("CD160", "CD160VEM")),
                                                   class = "states-to-compare-column"),
                                            column(6,
-                                                  tags$button("Adjust colors",
-                                                              class = "collapse-button",
-                                                              `data-toggle`="collapse",
-                                                              `data-target`="#colorss"),
+                                                  helper(tags$button("Adjust colors",
+                                                                     class = "collapse-button",
+                                                                     `data-toggle`="collapse",
+                                                                     `data-target`="#colorss"),
+                                                         content = "adjust_colors", type = "markdown", buttonLabel = "Okay", 
+                                                         easyClose = TRUE, colour = "#F8F1FF"),
                                                   tags$div(
                                                     class = "hideable",
                                                     id = "colorss",
@@ -113,38 +150,38 @@ ui <- fluidPage(theme = "HaDeX_theme.css",
                                          ##
                                          h4("Woods plot parameters:"),
                                          splitLayout(
-                                           selectInput(inputId = "state_first",
-                                                       label = "State 1",
-                                                       choices = c("CD160", "CD160_HVEM")),
-                                           selectInput(inputId = "state_second",
-                                                       label = "State 2", 
-                                                       choices = c("CD160", "CD160_HVEM"))
+                                           selectInput_h(inputId = "state_first",
+                                                         label = "State 1",
+                                                         choices = c("CD160", "CD160VEM")),
+                                           selectInput_h(inputId = "state_second",
+                                                         label = "State 2", 
+                                                         choices = c("CD160", "CD160VEM"))
                                          ),
                                          splitLayout(
-                                           selectInput(inputId = "confidence_limit",
-                                                       label = "Confidence limit 1:",
-                                                       choices = c("20%" = 0.2, "50%" = 0.5, "80%" = 0.8, "90%" = 0.9, "95%" = 0.95, "98%" = 0.98, "99%" = 0.99, "99.9%" = 0.999),
-                                                       selected = 0.98),
-                                           selectInput(inputId = "confidence_limit_2",
-                                                       label = "Confidence limit 2:",
-                                                       choices = c("20%" = 0.2, "50%" = 0.5, "80%" = 0.8, "90%" = 0.9, "95%" = 0.95, "98%" = 0.98, "99%" = 0.99, "99.9%" = 0.999),
-                                                       selected = 0.99)
+                                           selectInput_h(inputId = "confidence_limit",
+                                                         label = "Confidence limit 1:",
+                                                         choices = c("20%" = 0.2, "50%" = 0.5, "80%" = 0.8, "90%" = 0.9, "95%" = 0.95, "98%" = 0.98, "99%" = 0.99, "99.9%" = 0.999),
+                                                         selected = 0.98),
+                                           selectInput_h(inputId = "confidence_limit_2",
+                                                         label = "Confidence limit 2:",
+                                                         choices = c("20%" = 0.2, "50%" = 0.5, "80%" = 0.8, "90%" = 0.9, "95%" = 0.95, "98%" = 0.98, "99%" = 0.99, "99.9%" = 0.999),
+                                                         selected = 0.99)
                                          ),
                                          ##
-                                         h4("Adjust plot:"),
+                                         h4("Zoom:"),
                                          sliderInput(inputId = 'comp_plot_y_range',
                                                      label = 'Choose y range for comparison plot:',
-                                                     min = -2,
-                                                     max = 2,
-                                                     value = c(0, 1.2),
-                                                     step = 0.1,
+                                                     min = -200,
+                                                     max = 200,
+                                                     value = c(0, 120),
+                                                     step = 10,
                                                      width = "100%"),
                                          sliderInput(inputId = 'woods_plot_y_range',
                                                      label = 'Choose y range for Woods plot:',
-                                                     min = -2,
-                                                     max = 2,
-                                                     value = c(-.5, .5),
-                                                     step = 0.1),
+                                                     min = -200,
+                                                     max = 200,
+                                                     value = c(-50, 50),
+                                                     step = 10),
                                          sliderInput(inputId = 'plot_x_range',
                                                      label = 'Choose x range for both plots:',
                                                      min = 0,
@@ -184,22 +221,24 @@ ui <- fluidPage(theme = "HaDeX_theme.css",
                                          tabsetPanel(
                                            tabPanel("Comparison plot", 
                                                     br(),
-                                                    withSpinner(plotOutput("comparisonPlot")), 
+                                                    plotOutput_h("comparisonPlot", hover = hoverOpts("comparisonPlot_hover", delay = 10, delayType = "debounce")), 
                                                     downloadButton("comparisonPlot_download_button", 
                                                                    "Save chart (.svg)")), 
                                            tabPanel("Data",
                                                     br(),
                                                     DT::dataTableOutput("comparisonPlot_data"))),
+                                         uiOutput("comparisonPlot_debug"), 
                                          br(),
                                          tabsetPanel(
                                            tabPanel("Woods plot",
                                                     br(),
-                                                    withSpinner(plotOutput("differentialPlot")),
+                                                    plotOutput_h("differentialPlot", hover = hoverOpts("differentialPlot_hover", delay = 10, delayType = "debounce")), 
                                                     downloadButton("differentialPlot_download_button", 
                                                                    "Save chart (.svg)")), 
                                            tabPanel("Data",
                                                     br(),
-                                                    DT::dataTableOutput("differentialPlot_data")))
+                                                    DT::dataTableOutput("differentialPlot_data"))),
+                                         uiOutput("differentialPlot_debug")
                                          
                                        )
                               ),
@@ -272,19 +311,15 @@ ui <- fluidPage(theme = "HaDeX_theme.css",
                                                         selected = c("philic", "phobic"))
                                                ),
                                                column(6,
-                                                      numericInput(inputId = "sequence_length",
-                                                                   label = "Correct sequence length:",
-                                                                   value = 300, 
-                                                                   step = 1),
-                                                      h5("If C-terminal of is not covered by peptides, 
-                                               enter its correct position."),
-                                                      textOutput("sequence_length_exp_info")
+                                                      br()
                                                )
                                              )
                                            ),
                                            mainPanel(withSpinner(plotOutput("aminoDist")),
                                                      downloadButton("aminoDist_download_button",
-                                                                    "Save chart (.svg)")))
+                                                                    "Save chart (.svg)"),
+                                                     p("Source: Kyte, J., and Doolittle, R.F. (1982). A simple method for displaying the hydropathic character of a protein. J Mol Biol 157, 105–132.")),
+                                         )
                                        )
                               ),
                               tabPanel("Kinetics",
@@ -292,30 +327,34 @@ ui <- fluidPage(theme = "HaDeX_theme.css",
                                        sidebarPanel(
                                          class = "scrollable",
                                          h3("Select parameters for the plot."),
-                                         checkboxInput(inputId = "kin_theory",
-                                                       label = "Theoretical calculations",
-                                                       value = FALSE),
-                                         radioButtons(inputId = "kin_calc_type",
-                                                      label = "Choose values type:",
-                                                      choices = c("relative", "absolute"),
-                                                      selected = "relative"),
+                                         checkboxInput_h(inputId = "kin_theory",
+                                                         label = "Theoretical calculations",
+                                                         value = FALSE),
+                                         radioButtons_h(inputId = "kin_calc_type",
+                                                        label = "Choose values type:",
+                                                        choices = c("relative", "absolute"),
+                                                        selected = "relative"),
                                          h5("Choose time parameters:"),
                                          splitLayout(
-                                           selectInput(inputId = "kin_in_time",
-                                                       label = "IN",
-                                                       choices = c("0", "1", "5", "25", "1440")),
-                                           selectInput(inputId = "kin_out_time",
-                                                       label = "OUT",
-                                                       choices = c("0", "1", "5", "25", "1440"))),
+                                           selectInput_h(inputId = "kin_in_time",
+                                                         label = "IN",
+                                                         choices = c("0", "1", "5", "25", "1440")),
+                                           selectInput_h(inputId = "kin_out_time",
+                                                         label = "OUT",
+                                                         choices = c("0", "1", "5", "25", "1440"))),
                                          h5("Choose peptide:"),
-                                         DT::dataTableOutput("peptide_list_data"),
+                                         dataTableOutput_h("peptide_list_data"), ## !! 
+                                         actionButton(inputId = "reset_peptide_list", 
+                                                      label = "Reset chosen peptides"),
+                                         br(),
+                                         br(),
                                          br(),
                                          sliderInput(inputId = 'kin_plot_y_range',
                                                      label = 'Choose y range for kinetic plot:',
-                                                     min = -.5,
-                                                     max = 2,
-                                                     value = c(-.1, 1),
-                                                     step = 0.1),
+                                                     min = -50,
+                                                     max = 200,
+                                                     value = c(-10, 100),
+                                                     step = 10),
                                          tags$button("Adjust labels", 
                                                      class = "collapse-button",
                                                      `data-toggle`="collapse",
@@ -339,12 +378,47 @@ ui <- fluidPage(theme = "HaDeX_theme.css",
                                            tabPanel(
                                              "Kinetic plot",
                                              br(),
-                                             withSpinner(plotOutput("kinetic_plot_chosen_peptides", height = 600)),
+                                             plotOutput_h("kinetic_plot_chosen_peptides", height = 600),
                                              downloadButton("kineticPlot_download_button", 
                                                             "Save chart (.svg)")),
                                            tabPanel("Data", 
                                                     br(), 
-                                                    DT::dataTableOutput("kin_plot_data"))
+                                                    DT::dataTableOutput("kin_plot_data")) 
+                                         )
+                                       )
+                              ),
+                              #
+                              tabPanel("Quality control",
+                                       br(),
+                                       sidebarPanel(
+                                         h3("Select parameters for the plot."),
+                                         h5("The plot can be rendered only for relative experimental values."),
+                                         selectInput_h(inputId = "qc_in_time",
+                                                       label = "Choose in time: ",
+                                                       choices = c("0", "1", "5", "25", "1440")),
+                                         selectInput_h(inputId = "qc_chosen_time",
+                                                       label = "Choose time: ",
+                                                       choices = c("0", "1", "5", "25", "1440")),
+                                         selectInput_h(inputId = "qc_state_first",
+                                                       label = "State 1",
+                                                       choices = c("CD160", "CD160VEM")),
+                                         selectInput_h(inputId = "qc_state_second",
+                                                       label = "State 2", 
+                                                       choices = c("CD160", "CD160VEM"))
+                                       ),
+                                       mainPanel(
+                                         tabsetPanel(
+                                           tabPanel("Quality control plot", 
+                                                    br(),
+                                                    plotOutput_h("quality_control_plot", height = 600),
+                                                    downloadButton("quality_control_plot_download_button", 
+                                                                   "Save chart (.svg)"),
+                                                    br(),
+                                                    h4("This function plots the change in the uncertainty of deuteration levels as a function of incubation time. The uncertainty is averaged over all peptides available at a given time point in a selected state. This chart has a double function: firstly, it allows checking if the measurement uncertainty is decreasing over time (which is the expected behaviour) and the second one helps to plan the appropriate incubation length for the tested protein (whether we obtain the desired data reliability values).")
+                                                    ), 
+                                           tabPanel("Data",
+                                                    br(),
+                                                    DT::dataTableOutput("quality_control_plot_data"))
                                          )
                                        )
                               ),
@@ -384,6 +458,9 @@ ui <- fluidPage(theme = "HaDeX_theme.css",
                                                                            value = FALSE),
                                                              checkboxInput(inputId = "export_theo_kin_plot",
                                                                            label = "Theoretical Kinetic Plot", 
+                                                                           value = FALSE),
+                                                             checkboxInput(inputId = "export_quality_control_plot",
+                                                                           label = "Quality Control Plot",
                                                                            value = FALSE)),
                                                       column(6, 
                                                              checkboxInput(inputId = "export_overlap_dist_data",
@@ -401,7 +478,9 @@ ui <- fluidPage(theme = "HaDeX_theme.css",
                                                              checkboxInput(input = "export_kin_plot_data", 
                                                                            label = "Kinetic Plot Data"),
                                                              checkboxInput(inputId = "export_theo_kin_plot_data", 
-                                                                           label = "Theoretical Kinetic Plot Data"))),
+                                                                           label = "Theoretical Kinetic Plot Data"),
+                                                             checkboxInput(inputId = "export_quality_control_plot_data",
+                                                                           label = "Quality Control Plot Data"))),
                                                     br(),
                                                     h5("Elements chosen for report have the same parameters as chosen in panel e.g. axis range and title. Adjust parameters for plots as needed in the report."),
                                                     br(),
